Conspiracies
================================



Where to ask questions?
^^^^^^^^^^^^^^^^^^^^^^^^

To ask report issues or request features, please use the
`GitHub Issue Tracker <https://github.com/centre-for-humanities-computing/conspiracies/issues>`__.
Questions related to SpaCy are kindly referred to the SpaCy GitHub or forum. Otherwise,
please use the discussion Forums.

+------------------------------+-------------------------+
| Type                         |                         |
+------------------------------+-------------------------+
| **Bug Reports**              | `GitHub Issue Tracker`_ |
+------------------------------+-------------------------+
| **Feature Requests & Ideas** | `GitHub Issue Tracker`_ |
+------------------------------+-------------------------+
| **Usage Questions**          | `GitHub Discussions`_   |
+------------------------------+-------------------------+
| **General Discussion**       | `GitHub Discussions`_   |
+------------------------------+-------------------------+

.. _GitHub Issue Tracker: https://github.com/centre-for-humanities-computing/conspiracies/issues
.. _GitHub Discussions: https://github.com/centre-for-humanities-computing/conspiracies/discussions
  

.. toctree::
   :maxdepth: 4
   :caption: Getting started
   :hidden:

   installation
   tutorials/overview
   faq


.. toctree::
   :hidden:
   
   Changelog <https://github.com/centre-for-humanities-computing/conspiracies/blob/main/CHANGELOG.md>


.. toctree::
   :hidden:
   
   GitHub Repository <https://github.com/centre-for-humanities-computing/conspiracies>


Indices and search
==================

* :ref:`genindex`
* :ref:`search`
